*********
sge.input
*********

.. This file has been dedicated to the public domain, to the extent
   possible under applicable law, via CC0. See
   http://creativecommons.org/publicdomain/zero/1.0/ for more
   information. This file is offered as-is, without any warranty.

.. contents::

.. automodule:: sge.input

Input Event Classes
===================

.. autoclass:: sge.input.KeyPress

.. autoclass:: sge.input.KeyRelease

.. autoclass:: sge.input.MouseMove

.. autoclass:: sge.input.MouseButtonPress

.. autoclass:: sge.input.MouseButtonRelease

.. autoclass:: sge.input.JoystickAxisMove

.. autoclass:: sge.input.JoystickHatMove

.. autoclass:: sge.input.JoystickTrackballMove

.. autoclass:: sge.input.JoystickButtonPress

.. autoclass:: sge.input.JoystickButtonRelease

.. autoclass:: sge.input.KeyboardFocusGain

.. autoclass:: sge.input.KeyboardFocusLose

.. autoclass:: sge.input.MouseFocusGain

.. autoclass:: sge.input.MouseFocusLose

.. autoclass:: sge.input.QuitRequest
